<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nb">
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>License</source>
        <translation>Lisens</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="43"/>
        <location filename="../about.cpp" line="53"/>
        <source>Changelog</source>
        <translation>Endringslogg</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="44"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="64"/>
        <source>&amp;Close</source>
        <translation>&amp;Lukk</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>GUI for applying assorted useful tweaks</source>
        <translation>Grafisk grensesnitt for å aktivere diverse nyttige finjusteringer</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>launches brightness-systray</source>
        <translation>legger verktøy for justering av lysstyrke i systemkurven</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>opens with display tab open.  Only valid with Xfce desktop running</source>
        <translation>åpner med Vis-fanen åpen. Kun gyldig når skrivebordsmiljøet Xfce kjører</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="60"/>
        <source>Opens theme tab directly.  Valid on Xfce &amp; Fluxbox desktops</source>
        <translation>Åpner Tema-fanen direkte. Kun gyldig for skrivebordsmiljøene Xfce og Fluxbox</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>Display additional debug output in console</source>
        <translation>Vis ytterligere feilsøkingsdata i terminalen</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>Opens Other tab directly.  Valid on all desktops</source>
        <translation>Åpner Andre-fanen direkte. Gyldig for alle skrivebordsmiljø</translation>
    </message>
</context>
<context>
    <name>Tweak</name>
    <message>
        <location filename="../tweak.ui" line="14"/>
        <location filename="../tweak.cpp" line="71"/>
        <location filename="../tweak.cpp" line="242"/>
        <location filename="../tweak.cpp" line="261"/>
        <source>MX Tweak</source>
        <translation>MX Tweak</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="33"/>
        <source>Xfce Panel</source>
        <translation>Xfce-panel</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="39"/>
        <location filename="../tweak.ui" line="233"/>
        <location filename="../tweak.ui" line="520"/>
        <location filename="../tweak.ui" line="599"/>
        <location filename="../tweak.ui" line="655"/>
        <location filename="../tweak.ui" line="682"/>
        <location filename="../tweak.ui" line="874"/>
        <location filename="../tweak.ui" line="1265"/>
        <location filename="../tweak.ui" line="1394"/>
        <location filename="../tweak.ui" line="1441"/>
        <location filename="../tweak.ui" line="1532"/>
        <source>Apply</source>
        <extracomment>apply changes</extracomment>
        <translation>Bruk</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="58"/>
        <source>Tasklist</source>
        <translation>Tasklist</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="64"/>
        <source>Set Tasklist plugin to:</source>
        <translation>Velg Tasklist-programtillegg:</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="71"/>
        <source>Docklike is the modern dock plugin for the panel. Window Buttons is the classic tasklist without dock features.</source>
        <translation>«Docklike» er et moderne programtillegg for panelet. «Window Buttons» er den klassiske kjørelista uten dokk.</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="78"/>
        <source>Tasklist Options</source>
        <translation>Alternativer for Tasklist</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="85"/>
        <source>Docklike Options</source>
        <translation>Alternativer for Docklike</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="95"/>
        <source>Affects 1st Panel</source>
        <translation>Påvirker første panel</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="101"/>
        <location filename="../tweak.ui" line="1048"/>
        <location filename="../tweak.ui" line="1158"/>
        <location filename="../tweak.ui" line="1285"/>
        <source>Placement</source>
        <translation>Plassering</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="114"/>
        <source>Backup/Restore Configuration (all panels)</source>
        <translation>Reservekopier/gjenopprett oppsett (alle paneler)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="127"/>
        <source>Backup current panel configuration</source>
        <translation>Reservekopier gjeldende paneloppsett</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="141"/>
        <source>Restore selected panel configuration</source>
        <translation>Gjenopprett valgt paneloppsett</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="148"/>
        <source>Restore default panel</source>
        <translation>Gjenopprett standard panel</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="158"/>
        <source>Panel Plugin Scales</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="164"/>
        <source>Volume</source>
        <extracomment>volume plugin scale factor</extracomment>
        <translation>Dataområde</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="184"/>
        <source>Power Manager</source>
        <extracomment>power manager plugin scale factor</extracomment>
        <translation>Strømstyring</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="221"/>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="227"/>
        <source>Theme Options</source>
        <translation>Alternativer for tema</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="262"/>
        <source>Remove User Theme Set</source>
        <translation>Fjern brukers temasett</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="275"/>
        <source>Themes</source>
        <translation>Temaer</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="281"/>
        <source>Application</source>
        <extracomment>theme an application will get</extracomment>
        <translation>Program</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="301"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Toggle Dark Mode for GTK4 libadwaita applications&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Veksle mørk modus for GTK4 libadwaita-programmer&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="304"/>
        <source>Dark Mode</source>
        <translation>Mørk modus</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="311"/>
        <location filename="../tweak.ui" line="1778"/>
        <source>Window Manager</source>
        <extracomment>theme a window manager border will get</extracomment>
        <translation>Vindusbehandler</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="331"/>
        <source>Legacy Styles</source>
        <translation>Utdaterte stiler</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="344"/>
        <source>Icons</source>
        <extracomment>icon theme</extracomment>
        <translation>Ikoner</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="351"/>
        <source>Cursors</source>
        <extracomment>cursor theme</extracomment>
        <translation>Pekere</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="358"/>
        <source>Save Current Settings as a Theme Set</source>
        <extracomment>save theme settings as a group</extracomment>
        <translation>Lagre gjeldende innstillinger som et temasett</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="368"/>
        <source>Size</source>
        <extracomment>size of the cursor</extracomment>
        <translation>Str</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="378"/>
        <source>default</source>
        <extracomment>default cursor size determined by X server</extracomment>
        <translation>forvalgt</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="401"/>
        <location filename="../tweak.ui" line="453"/>
        <source>Compositor</source>
        <translation>Kompositt</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="413"/>
        <source>Changing the VBlank mode may help alleviate some screen tearing issues. See Help for more information.</source>
        <translation>Riktig VBlank-modus kan forhindre oppbryting av grafikken («tearing»). Se hjelpeteksten for mer informasjon.</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="416"/>
        <source>VBlank</source>
        <translation>VBlank</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="424"/>
        <source>auto</source>
        <translation>auto</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="429"/>
        <source>glx</source>
        <translation>glx</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="434"/>
        <source>xpresent</source>
        <translation>xpresent</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="439"/>
        <location filename="../tweak.ui" line="1022"/>
        <source>off</source>
        <extracomment>setting to 0 turns off screensaver screen blank</extracomment>
        <translation>av</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="447"/>
        <source>Transparency and shadow options</source>
        <translation>Alternativer for gjennomsiktighet og skygger</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="463"/>
        <source>Xfce Compositor Settings</source>
        <translation>Innstilling av Xfwm-komposittmotor</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="466"/>
        <source>Xfwm Settings</source>
        <translation>Innstillinger for Xfwm</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="476"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>Kjør oppsettsverktøyet compton-conf</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="479"/>
        <source>Picom settings</source>
        <translation>Picom-innstillinger</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="490"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>Rediger compton.conf direkte i tekstprogram</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="493"/>
        <source>Edit picom.conf</source>
        <translation>Rediger picom.conf</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="540"/>
        <source>Display</source>
        <translation>Skjerm</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="546"/>
        <source>Display Tweaks</source>
        <translation>Finjustering av skjerm</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="552"/>
        <source>Hardware Backlight</source>
        <extracomment>set the hardware backlight on monitors that have them</extracomment>
        <translation>Skjermens bakbelysning</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="575"/>
        <location filename="../tweak.ui" line="706"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="582"/>
        <source>GTK scaling</source>
        <extracomment>gtk scale factor</extracomment>
        <translation>GTK-skalering</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="635"/>
        <source>Choose Display for xrandr tweaks</source>
        <extracomment>choose the display that the xrandr tweaks will be acted upon</extracomment>
        <translation>Velg skjerm for finjustering av xrandr</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="645"/>
        <source>Resolution</source>
        <translation>Oppløsning</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="662"/>
        <source>xrandr Scaling</source>
        <extracomment>xrandr scale factor</extracomment>
        <translation>xrandr-skalering</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="689"/>
        <source>Software (xrandr) Brightness</source>
        <extracomment>adjust brightness (not backlight) via software</extracomment>
        <translation>Lysstyrke (xrandr)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="713"/>
        <source>Saving is per display</source>
        <translation>Lagres separat for skjerm</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="716"/>
        <source>Save</source>
        <translation>Lagre</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="740"/>
        <source>Xfce</source>
        <translation>Xfce</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="746"/>
        <source>Desktop</source>
        <translation>Skrivebord</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="752"/>
        <source>Enable single-click on desktop</source>
        <translation>Slå på enkelt-klikking på skrivebordet</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="759"/>
        <source>Enable Desktop Zoom </source>
        <translation>Slå på skrivebords-zoom</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="766"/>
        <location filename="../tweak.ui" line="1355"/>
        <source>Show windows from all workspaces in panel</source>
        <translation>Vis vinduer fra alle arbeidsområder i panelet</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="773"/>
        <source>Do not shorten file names on the desktop</source>
        <translation>Ikke forkort filnavn på skrivebordet</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="783"/>
        <source>Thunar</source>
        <translation>Thunar</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="789"/>
        <source>Enable single-click in Thunar File Manager</source>
        <translation>Slå på enkelt-klikking i filbehandleren Thunar</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="796"/>
        <source>Reset custom right-click actions to system defaults</source>
        <translation>Tilbakestill tilpassede høyreklikk-handlinger til systemets forvalgte</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="803"/>
        <source>Thunar windows always open in split view</source>
        <translation>Åpne alltid Thunar med kløyvd visning</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="810"/>
        <source>Thunar split view opens horizontal</source>
        <translation>Åpne kløyvd visning i Thunar vannrett</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="820"/>
        <source>Show percentages in notifcations when available</source>
        <translation>Vis prosentdel i varslinger hvis tilgjengelig</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="827"/>
        <source>Show GTK File Dialog action buttons at bottom of dialogs</source>
        <translation>Vis knapper i GTK-fildialogen i bunnen av vinduet</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="834"/>
        <source>(also turns off Client Side Decorations for Xfce applications)</source>
        <translation>(slår også av klientsidedekorasjoner (CSD) for Xfce-programmer)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="844"/>
        <source>Enable hibernate on Log Out menu </source>
        <translation>Vis dvalemodus i utloggingsmenyen</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="851"/>
        <source>note: to hibernate, swap needs to be &gt;= RAM</source>
        <translation>merk: dvalemodus krever vekselminne &gt;= RAM</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="885"/>
        <source>Fluxbox</source>
        <translation>Fluxbox</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="891"/>
        <location filename="../tweak.ui" line="1365"/>
        <source>Reset Defaults</source>
        <translation>Gjenopprett standardverdier</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="897"/>
        <source>Reset DefaultDock</source>
        <translation>Gjenopprett standard dokk</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="904"/>
        <source>Reset Fluxbox Menu</source>
        <translation>Tilbakestill Fluxbox-menyen</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="911"/>
        <source>Reset ALL mx-fluxbox settings</source>
        <translation>Tilbakestill ALLE mx-fluxbox-innstillinger</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="918"/>
        <source>Add new default menu items, if any, to existing fluxbox menu.</source>
        <translation>Legg til nye standard menyelementer, hvis noen, til eksisterende fluxbox-meny.</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="921"/>
        <source>Upgrade existing menu entries</source>
        <translation>Oppgrader eksisterende menyoppføringer</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="931"/>
        <source>Desktop Icons</source>
        <translation>Skrivebordsikoner</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="937"/>
        <source>Toggle desktop icons</source>
        <translation>Veksle skrivebordsikoner</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="945"/>
        <location filename="../tweak.ui" line="969"/>
        <source>On</source>
        <translation>På</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="950"/>
        <location filename="../tweak.ui" line="974"/>
        <source>Off</source>
        <translation>Av</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="958"/>
        <source>Toggle icon captions</source>
        <translation>Veksle ikontitler</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="979"/>
        <source>On Hover</source>
        <translation>Når musepeker holdes over</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1006"/>
        <source>Screensaver</source>
        <translation>Skjermsparer</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1012"/>
        <source>Idle time (minutes)</source>
        <extracomment>set the time of inactivity  before screensaver screen blank occurs</extracomment>
        <translation>Ventetid (minutter)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1035"/>
        <source>Toolbar Settings</source>
        <translation>Innstilling av verktøylinje</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1041"/>
        <source>Height</source>
        <translation>Høyde</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1122"/>
        <location filename="../tweak.ui" line="1232"/>
        <source>Autohide</source>
        <translation>Autoskjul</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1129"/>
        <source>Show Toolbar</source>
        <translation>Vis verktøylinje</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1136"/>
        <source>Width</source>
        <translation>Bredde</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1152"/>
        <source>Dock Settings</source>
        <translation>Dokk-innstillinger</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1239"/>
        <source>Manage Tint2 Panel</source>
        <translation>Behandle Tint2-panel</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1273"/>
        <source>Plasma</source>
        <translation>Plasma</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1279"/>
        <source>Affects 1st panel</source>
        <translation>Påvirker første panel</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1296"/>
        <source>Bottom</source>
        <translation>Bunn</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1301"/>
        <source>Left</source>
        <translation>Venstre</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1306"/>
        <source>Top</source>
        <translation>Topp</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1311"/>
        <source>Right</source>
        <translation>Høyre</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1335"/>
        <source>Workspace</source>
        <translation>Arbeidsområde</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1341"/>
        <source>Autostart plasma-discover system tray update notification utility</source>
        <extracomment>enable or disable autostartup of plasma-discover updater utility on login</extracomment>
        <translation>Start automatisk verktøyet «plasma-discover». oppdateringsvarsel i systemkurven</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1348"/>
        <source>Enable single-click</source>
        <translation>Slå på enkelt-klikk</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1371"/>
        <source>Reset KDE/Plasma defaults</source>
        <translation>Gjenopprett til KDE/Plasma-forvalg</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1405"/>
        <source>Super Key</source>
        <extracomment>referring to the meta or Left Super Key</extracomment>
        <translation>Super-tast</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1411"/>
        <source>Also known as the &quot;windows&quot; key</source>
        <translation>Også kjent som «Windows»-knappen</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1414"/>
        <source>Command to run with Super (Meta) key</source>
        <extracomment>label for the field to enter the command to use with super key</extracomment>
        <translation>Kommando som Super (Meta)-tasten skal kjøre</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1424"/>
        <source>xfce-superkey defaults</source>
        <extracomment>indicates that xfce-superkey will select a command by its default logic</extracomment>
        <translation>Forvalg for Xfce-supertast </translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1431"/>
        <source>Choose application</source>
        <extracomment>description of button action to launch file dialog to choose an application</extracomment>
        <translation>Velg program</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1462"/>
        <source>Miscellaneous</source>
        <translation>Diverse</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1518"/>
        <source>Reset Lightdm (login screen) to system default theme</source>
        <translation>Gjenopprett Lightdm (innloggingsskjerm) til systemets forvalgte tema</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1623"/>
        <source>Enable mounting of internal drives by non-root users</source>
        <translation>La vanlige brukere montere interne disker</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1616"/>
        <source>Enable kernel sandbox</source>
        <translation>Slå på kjerne-sandkasse</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1566"/>
        <source>requires reboot</source>
        <translation>krever omstart</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1569"/>
        <source>Enable Bluetooth adapters on boot</source>
        <translation>Slå på blåtann-adaptere ved oppstart</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1694"/>
        <source>Enable Bluetooth battery info for connected devices (requires system restart)</source>
        <extracomment>expose battery info for connected bluetooth devices to the operating system via dbus</extracomment>
        <translation>Slå på batteriinfo via blåtann for tilkoblede enheter (krever omstart av systemet)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1491"/>
        <source>Early loading of KVM module is new to  kernel 6.12 and conflicts with some non-KVM virtual machine applications, including virtualbox</source>
        <extracomment>early loading is new on 6.12 kernel and conflicts with virtualbox</extracomment>
        <translation>Tidlig innlasting av KVM-modul er ny i kjerne 6.12 og har konflikt med noen virtuell maskin-programmer som ikke bruker KVM, blant annet virtualbox</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1494"/>
        <source>Disable early KVM module load (must be disabled for Virtualbox operation on kernel 6.12 and up)</source>
        <extracomment>disable early loading of KVM module.  necessary for virtualbox to function with kernels 6.12 and up.  actually default behavior on kernels 6.11 and earlier.</extracomment>
        <translation>Slå av tidlig innlasting av KVM (må slås av for Virtualbox for kjerne 6.12 og senere)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1630"/>
        <source>Apt installs additional &quot;recommends&quot; packages as dependencies</source>
        <translation>Apt installerer ytterligere anbefalte pakker som avhengigheter</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1576"/>
        <source>Generate fluxbox All Apps menu after package installation, removal, and updates</source>
        <translation>Lag «Alle programmer»-meny for fluxbox etter pakkeinstallasjoner, fjerninger og oppdateringer</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1609"/>
        <source>Use Client Side Decorations (CSD) on GTK3 applications that support them (requires session restart)</source>
        <translation>Bruk klientsidedekorasjoner (CSD) for GTK3-programmer som støtter dem (krever omstart av økt)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1508"/>
        <source>put a hold or remove a hold on updates of Liquorix kernels</source>
        <extracomment>toggle for apt hold action on update meta packages</extracomment>
        <translation>hold fast eller tillat oppdatering av Liquorix-kjerner</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1511"/>
        <source>Enable Automatic Liquorix Kernel Updates (MX ahs repository)</source>
        <extracomment>uses apt-mark to hold or unhold updates to kernel metapackages</extracomment>
        <translation>Slå på automatisk oppdatering av Liquorix-kjerner (MX ahs)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1684"/>
        <source>put a hold or remove a hold on updates of Debian  kernels</source>
        <extracomment>toggle for apt hold action on update meta packages</extracomment>
        <translation>hold fast eller tillat oppdatering av Debian-kjerner</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1687"/>
        <source>Enable Automatic Debian Kernel Updates</source>
        <extracomment>uses apt-mark to hold or unhold updates to kernel metapackages</extracomment>
        <translation>Slå på automatisk oppdatering av Debian-kjerner</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1637"/>
        <source>Use intel driver instead of default &quot;modesetting&quot; driver (requires restart)</source>
        <translation>Bruk intel-driver istedenfor den vanlige «modesetting»-driveren (krever omstart)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1471"/>
        <source>NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
        <translation>MERK: eksisterende /etc/X11/xorg.conf.d/20-intel.conf vil reservekopieres til hjemmemappa</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1583"/>
        <source>Use tearfree amdgpu option</source>
        <translation>Slå på alternativet «TearFree» i AMDGPU </translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1545"/>
        <source>NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
        <translation>MERK: eksisterende /etc/X11/xorg.conf.d/20-amd.conf vil reservekopieres til hjemmemappa</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1525"/>
        <source>Use tearfree radeon driver option</source>
        <translation>Slå på alternativet «TearFree» i Radeon-driveren</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1501"/>
        <source>NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
        <translation>MERK: eksisterende /etc/X11/xorg.conf.d/20-radeon.conf vil reservekopieres til hjemmemappa</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1559"/>
        <source>Change computer name (requires reboot)</source>
        <extracomment>option to change the system hostname, requires a reboot to be 100% effective</extracomment>
        <translation>Endre datamaskinens navn (krever omstart)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1552"/>
        <source>Change Default Display Manager (login screen) (requires reboot)</source>
        <extracomment>option to change display manager login screen.  present if more than one display manager is installed</extracomment>
        <translation>Endre standard innloggingsbehandler (krever omstart)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1647"/>
        <source>Password for administrative tasks:</source>
        <translation>Passord for administrative oppgaver:</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1654"/>
        <source>&amp;User</source>
        <translation>&amp;Bruker</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1661"/>
        <source>Root</source>
        <translation>Root</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1701"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Init system that is used as the default on the main grub boot menu entry&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1704"/>
        <source>Change Default Init System</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1729"/>
        <source>Xfce Settings</source>
        <translation>Xfce-innstillinger</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1735"/>
        <source>Customize the panel</source>
        <translation>Tilpass utseende</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1745"/>
        <source>Panel</source>
        <translation>Panel</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1765"/>
        <source>Configure window behavior and shortcuts</source>
        <translation>Sett opp vindusoppførsel og hurtigtaster</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1798"/>
        <source>Customize the look of your desktop</source>
        <translation>Tilpass skrivebordets utseende</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1811"/>
        <source>Appearance</source>
        <translation>Utseende</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1823"/>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1833"/>
        <source>Help</source>
        <translation>Hjelp</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1891"/>
        <source>Quit application</source>
        <translation>Avslutt programmet</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1894"/>
        <source>Close</source>
        <translation>Lukk</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1900"/>
        <source>Alt+N</source>
        <translation>Alt + N</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="72"/>
        <source>--display switch only valid for Xfce</source>
        <translation>Bryteren --display kun gyldig for Xfce</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="241"/>
        <source>About MX Tweak</source>
        <translation>Om MX Tweak</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="243"/>
        <source>Version: </source>
        <translation>Versjon:</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="244"/>
        <source>App for quick default ui theme changes and tweaks</source>
        <translation>Program for finjusteringer og endringer av standard tema for brukergrensesnitt</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="246"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Opphavsrett (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="247"/>
        <source>%1 License</source>
        <translation>Lisens for %1</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="261"/>
        <source>%1 Help</source>
        <translation>Hjelpetekst for %1</translation>
    </message>
</context>
<context>
    <name>TweakCompositor</name>
    <message>
        <location filename="../tweak_compositor.cpp" line="62"/>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <location filename="../tweak_compositor.cpp" line="63"/>
        <source>Xfwm (Xfce) Compositor</source>
        <translation>Xfwm (Xfce) komposittmotor</translation>
    </message>
    <message>
        <location filename="../tweak_compositor.cpp" line="64"/>
        <source>Picom</source>
        <translation>Picom</translation>
    </message>
</context>
<context>
    <name>TweakMisc</name>
    <message>
        <location filename="../tweak_misc.cpp" line="305"/>
        <source>Please enter a computer name.</source>
        <comment>question to enter a name for the computer hostname</comment>
        <translation>Skriv inn datamaskinens navn.</translation>
    </message>
    <message>
        <location filename="../tweak_misc.cpp" line="309"/>
        <source>Sorry, your computer name contains invalid characters.
You'll have to select a different
name before proceeding.</source>
        <comment>unacceptable characters are found in hostname, pick a new name</comment>
        <translation>Datamaskinens navn kan ikke inneholde ugyldige tegn.
Velg et annet navn.</translation>
    </message>
</context>
<context>
    <name>TweakSuperKey</name>
    <message>
        <location filename="../tweak_superkey.cpp" line="43"/>
        <source>Select application to run</source>
        <comment>will show in file dialog when selection an application to run</comment>
        <translation>Velg program som skal kjøres</translation>
    </message>
</context>
<context>
    <name>TweakTheme</name>
    <message>
        <location filename="../tweak_theme.cpp" line="64"/>
        <source>Plasma Widget Themes</source>
        <comment>theme style of the kde plasma widgets</comment>
        <translation>Temaer for Plasmas skjermelementer</translation>
    </message>
    <message>
        <location filename="../tweak_theme.cpp" line="65"/>
        <source>Color Schemes</source>
        <comment>plasma widget color schemes</comment>
        <translation>Fargeskjemaer</translation>
    </message>
    <message>
        <location filename="../tweak_theme.cpp" line="66"/>
        <source>Plasma Look &amp; Feel Global Themes</source>
        <comment>plasma global themes</comment>
        <translation>Globale temaer for Plasma (utseende og oppførsel)</translation>
    </message>
    <message>
        <location filename="../tweak_theme.cpp" line="139"/>
        <source>Choose a theme set</source>
        <translation>Velg et temasett</translation>
    </message>
</context>
<context>
    <name>TweakXfcePanel</name>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="17"/>
        <source>Horizontal (Bottom)</source>
        <translation>Vannrett (bunn)</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="18"/>
        <source>Horizontal (Top)</source>
        <translation>Vannrett (topp)</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="20"/>
        <source>Vertical (Left)</source>
        <translation>Loddrett (venstre)</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="21"/>
        <source>Vertical (Right)</source>
        <translation>Loddrett (høyre)</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="23"/>
        <source>docklike</source>
        <translation>docklike</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="24"/>
        <source>Window Buttons</source>
        <translation>Vindusknapper</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="273"/>
        <location filename="../tweak_xfce_panel.cpp" line="280"/>
        <location filename="../tweak_xfce_panel.cpp" line="297"/>
        <location filename="../tweak_xfce_panel.cpp" line="301"/>
        <source>MX Tweak</source>
        <translation>MX Tweak</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="274"/>
        <source>Plese remove special characters</source>
        <translation>Fjern spesialtegn</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="274"/>
        <source>from file name</source>
        <translation>fra filnavn</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="280"/>
        <source>File name already exists.  Choose another name</source>
        <translation>Denne fila finnes allerede. Velg et annet navn</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="298"/>
        <source>File is not a valid tar.xz archive file</source>
        <translation>Denne fila er ikke et gyldig tar.xz-arkiv</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="302"/>
        <source>Archive does not contain a panel config</source>
        <translation>Arkivet inneholder ikke et paneloppsett</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="733"/>
        <source>Panel Preferences</source>
        <translation>Panelinnstillinger</translation>
    </message>
</context>
<context>
    <name>brightness_small</name>
    <message>
        <location filename="../brightness_small.ui" line="14"/>
        <source>MainWindow</source>
        <translation>MainWindow</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="34"/>
        <source>&gt;&gt;</source>
        <translation>&gt;&gt;</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="41"/>
        <source>Software (xrandr) Brightness</source>
        <translation>Lysstyrke (xrandr)</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="61"/>
        <location filename="../brightness_small.ui" line="89"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="68"/>
        <source>Save</source>
        <translation>Lagre</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="75"/>
        <source>Hardware Backlight</source>
        <translation>Skjermens bakbelysning</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="35"/>
        <source>Brightness</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="54"/>
        <source>Display</source>
        <translation>Skjerm</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="59"/>
        <source>&amp;Quit</source>
        <translation>&amp;Avslutt</translation>
    </message>
</context>
<context>
    <name>remove_user_theme_set</name>
    <message>
        <location filename="../remove_user_theme_set.ui" line="14"/>
        <source>Remove User Theme Set</source>
        <translation>Fjern brukers temasett</translation>
    </message>
</context>
<context>
    <name>theming_to_tweak</name>
    <message>
        <location filename="../theming_to_tweak.ui" line="14"/>
        <source>New Theme Set</source>
        <translation>Nytt temasett</translation>
    </message>
    <message>
        <location filename="../theming_to_tweak.ui" line="20"/>
        <source>Enter name for new theme set</source>
        <translation>Angi det nye temasettets navn</translation>
    </message>
</context>
<context>
    <name>window_buttons</name>
    <message>
        <location filename="../window_buttons.ui" line="14"/>
        <location filename="../window_buttons.cpp" line="38"/>
        <source>Window Buttons</source>
        <translation>Vindusknapper</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="23"/>
        <source>Appearance</source>
        <translation>Utseende</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="29"/>
        <source>Show button labels</source>
        <translation>Vis knappetekst</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="36"/>
        <source>Show flat buttons</source>
        <translation>Vis flate knapper</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="43"/>
        <source>Show handle</source>
        <translation>Vis håndtak</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="50"/>
        <source>Sorting Order:</source>
        <translation>Sorteringsrekkefølge:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="58"/>
        <source>Timestamp</source>
        <translation>Tidsstempel</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="63"/>
        <source>Group title and timestamp</source>
        <translation>Grupper tittel og tidsstempel</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="68"/>
        <source>Window Title</source>
        <translation>Vindustittel</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="73"/>
        <source>Group title and window title</source>
        <translation>Grupper tittel og vindustittel</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="78"/>
        <source>None, allow drag-and-drop</source>
        <translation>Ingen, tillatt dra-og-slipp</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="89"/>
        <source>Behavior</source>
        <translation>Oppførsel</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="95"/>
        <source>Window grouping:</source>
        <translation>Vindusgruppering:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="103"/>
        <source>Never</source>
        <translation>Aldri</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="108"/>
        <source>Always</source>
        <translation>Alltid</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="116"/>
        <source>Middle click action:</source>
        <translation>Handling ved midt-klikk:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="124"/>
        <source>Nothing</source>
        <translation>Ingenting</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="129"/>
        <source>Close window</source>
        <translation>Lukk vindu</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="134"/>
        <source>Minimize window</source>
        <translation>Minimer vindu</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="142"/>
        <source>Restore minimized windows to current workspace</source>
        <translation>Gjenopprett minimerte vinduer til gjeldende arbeidsområde</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="149"/>
        <source>Draw window frame when hovering over a button</source>
        <translation>Tegn vindusramme når peker svever over en knapp</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="156"/>
        <source>Switch windows using the mouse wheel</source>
        <translation>Bytt mellom vinduer med musehjulet</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="166"/>
        <source>Filtering</source>
        <translation>Filtrering</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="172"/>
        <source>Show windows from all workspaces or viewports</source>
        <translation>Vis vinduer fra alle arbeidsområder eller visningsområder</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="179"/>
        <source>Show only minimized windows</source>
        <translation>Vis kun minimerte vinduer</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="186"/>
        <source>Show windows from all monitors</source>
        <translation>Vis vinduer fra alle skjermer</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="210"/>
        <source>Close</source>
        <translation>Lukk</translation>
    </message>
</context>
<context>
    <name>xfwm_compositor_settings</name>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialogvindu</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="23"/>
        <source>Feature Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="29"/>
        <source>Display fullscreen overlay windows directly</source>
        <translation>Vis overleggsvinduer i fullskjerm direkte</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="36"/>
        <source>Synchronize drawing to vertical blank</source>
        <translation>Synkroniser uttegning til vertikal blank</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="43"/>
        <source>Show windows preview in place of icons when cycling</source>
        <translation>Vis forhåndsvisning av vinduer istedenfor ikoner ved blaing</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="50"/>
        <source>Show shadows under popup windows</source>
        <translation>Vis skygge under sprettoppvinduer</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="57"/>
        <source>Show shadows under dock windows</source>
        <translation>Vis skygge under dokk</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="64"/>
        <source>Show shadows under regular windows</source>
        <translation>Vis skygge under vanlige vinduer</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="74"/>
        <source>Opacity Settings</source>
        <translation>Innstillinger for gjennomsiktighet</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="80"/>
        <source>Window decorations</source>
        <translation>Vindusdekorasjoner</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="103"/>
        <source>Inactive windows</source>
        <translation>Passive vinduer</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="126"/>
        <source>Windows during move</source>
        <translation>Vinduer som dras</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="149"/>
        <source>Windows during resize</source>
        <translation>Vinduer som får endret størrelse</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="172"/>
        <source>Popup Windows</source>
        <translation>Sprettoppvinduer</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="205"/>
        <source>Close</source>
        <translation>Lukk</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.cpp" line="25"/>
        <source>Xfwm Compositor Settings</source>
        <translation>Innstilling av Xfwm-komposittmotor</translation>
    </message>
</context>
</TS>